export declare class Pool<T> {
    readonly init: () => T;
    readonly free: (item: T) => void;
    /**
     * The preferred size of the pool.
     * When you call `.fit()` on a pool, it shrinks to this size.
     */
    preferredSize: number;
    private _pool;
    private _count;
    constructor(init: () => T, free?: (item: T) => void, 
    /**
     * The preferred size of the pool.
     * When you call `.fit()` on a pool, it shrinks to this size.
     */
    preferredSize?: number);
    /**
     * Returns the pool's storage.
     *
     * This should not be modified, do so at your own risk.
     */
    get inner(): readonly T[];
    /**
     * The amount of objects currently in the pool.
     */
    get length(): number;
    /**
     * If there are objects in the pool, this returns one of them,
     * otherwise, it allocates a new object.
     */
    get(): T;
    /**
     * Return an object to the pool.
     */
    put(object: T): void;
    /**
     * Shrinks the pool to `pool.preferredSize` objects, discarding any extras.
     * Does nothing if there aren't more than `pool.preferredSize` objects in the pool.
     * Calls the provided `free(object)` for every discarded object.
     *
     * Internally, this moves the pool's elements into a new, smaller array.
     */
    fit(): void;
}
